==> violet-common-mybatis-1.0-20250903.052417-10-sources.jar: org/violet/common/mybatis/handler/CommonMetaObjectHandler.java <==
package org.violet.common.mybatis.handler;

import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.handlers.MetaObjectHandler;
import org.apache.ibatis.reflection.MetaObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.violet.common.core.enums.EmbedTableColumn;
import org.violet.common.core.intefaces.LoginUserId;
import org.violet.common.mybatis.base.BaseEntity;
import org.violet.common.security.util.SecurityUtil;

@Component
public class CommonMetaObjectHandler implements MetaObjectHandler {
    @Autowired
    LoginUserId loginUserId;

    public CommonMetaObjectHandler() {
    }

    public void insertFill(MetaObject metaObject) {
        if (metaObject.getOriginalObject() instanceof BaseEntity) {
            Long userId = this.getUserId();
            this.fillStrategy(metaObject, EmbedTableColumn.CREATE_TIME.filedName(), DateUtil.date());
            this.fillStrategy(metaObject, EmbedTableColumn.MODIFY_TIME.filedName(), DateUtil.date());
            this.fillStrategy(metaObject, EmbedTableColumn.CREATE_BY.filedName(), userId);
            this.fillStrategy(metaObject, EmbedTableColumn.MODIFY_BY.filedName(), userId);
        }
    }

    public void updateFill(MetaObject metaObject) {
        if (metaObject.getOriginalObject() instanceof BaseEntity) {
            Long userId = this.getUserId();
            this.fillStrategy(metaObject, EmbedTableColumn.MODIFY_TIME.filedName(), DateUtil.date());
            this.fillStrategy(metaObject, EmbedTableColumn.MODIFY_BY.filedName(), userId);
        }
    }

    private Long getUserId() {
        return SecurityUtil.getLoginUserId() != null
                ? SecurityUtil.getLoginUserId()
                : (this.loginUserId != null ? this.loginUserId.loginUserId() : 0L);
    }

}

==> violet-common-mybatis-1.1-20251112.080104-9-sources.jar: org/violet/common/mybatis/handler/CommonMetaObjectHandler.java <==
package org.violet.common.mybatis.handler;

import cn.dev33.satoken.stp.StpUtil;
import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.handlers.MetaObjectHandler;
import org.apache.ibatis.reflection.MetaObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.violet.common.core.constants.ComConst;
import org.violet.common.core.enums.EmbedTableColumn;
import org.violet.common.core.intefaces.LoginUserId;
import org.violet.common.mybatis.base.BaseEntity;
import org.violet.common.security.util.SecurityUtil;

@Component
public class CommonMetaObjectHandler implements MetaObjectHandler {
    @Autowired
    LoginUserId loginUserId;

    public CommonMetaObjectHandler() {
    }

    public void insertFill(MetaObject metaObject) {
        if (metaObject.getOriginalObject() instanceof BaseEntity) {
            Long userId = this.getUserId();
            this.fillStrategy(metaObject, EmbedTableColumn.CREATE_TIME.filedName(), DateUtil.date());
            this.fillStrategy(metaObject, EmbedTableColumn.MODIFY_TIME.filedName(), DateUtil.date());
            this.fillStrategy(metaObject, EmbedTableColumn.CREATE_BY.filedName(), userId);
            this.fillStrategy(metaObject, EmbedTableColumn.MODIFY_BY.filedName(), userId);
        }
    }

    public void updateFill(MetaObject metaObject) {
        if (metaObject.getOriginalObject() instanceof BaseEntity) {
            Long userId = this.getUserId();
            this.fillStrategy(metaObject, EmbedTableColumn.MODIFY_TIME.filedName(), DateUtil.date());
            this.fillStrategy(metaObject, EmbedTableColumn.MODIFY_BY.filedName(), userId);
        }
    }

    private Long getUserId() {
        try {
            return StpUtil.getLoginId(ComConst.DEF_ROOT_USER_ID);
        } catch (Exception e) {
//            log.info(e.getMessage());
            return ComConst.DEF_ROOT_USER_ID;
        }
    }

}
